|logo| Girder Worker |build-status| |docs-status| |license-badge| |gitter-badge|
================================================================================

A flexible, simple script execution engine that integrates with the
`Girder <http://girder.readthedocs.org>`_ data management system to run
distributed batch jobs.

The worker supports running tasks in many environments including Python, R,
and Docker, and supports fetching and pushing data to
and from various data sources, including Girder.

Visit the `documentation <http://girder-worker.readthedocs.org>`_ for more details and API documentation.

For questions, comments, or to get in touch with the maintainers, head to our `Gitter Forum
<https://gitter.im/girder/girder_worker>`_.

We'd love for you to `contribute to Girder Worker <CONTRIBUTING.md>`_.


.. |logo| image:: docs/static/favicon.png

.. |build-status| image:: https://travis-ci.org/girder/girder_worker.png?branch=master
    :target: https://travis-ci.org/girder/girder_worker
    :alt: Build Status

.. |docs-status| image:: https://readthedocs.org/projects/girder-worker/badge?version=latest
    :target: https://girder-worker.readthedocs.io
    :alt: Documentation Status

.. |license-badge| image:: docs/license.png
    :target: https://pypi.python.org/pypi/girder_worker
    :alt: License

.. |gitter-badge| image:: https://badges.gitter.im/Join Chat.svg
    :target: https://gitter.im/girder/girder_worker?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
    :alt: Gitter Chat
